@@ -7,7 +7,7 @@ from __future__ import print_function
     This uses the Python type P4API.P4Adapter, which is a wrapper for the
     Perforce ClientApi object.
     
-    $Id: //depot/r22.2/p4-python/P4.py#1 $
+    $Id: //depot/r25.2/p4-python/P4.py#1 $
     
     #*******************************************************************************
     # Copyright (c) 2007-2010, Perforce Software, Inc.  All rights reserved.
@@ -43,29 +43,59 @@ from __future__ import print_function
     See accompanying LICENSE.txt including for redistribution permission.
     """
 
-import sys, datetime
+import sys, datetime, time
 import re
 import shutil
 from contextlib import contextmanager
 import uuid, tempfile
 import os, os.path, platform
 import subprocess
+import threading
 
 # P4Exception - some sort of error occurred
 class P4Exception(Exception):
     """Exception thrown by P4 in case of Perforce errors or warnings"""
-    
+
     def __init__(self, value):
-        Exception.__init__(self)
-        
+        super().__init__(value)
         if isinstance(value, (list, tuple)) and len(value) > 2:
             self.value = value[0]
-            self.errors = value[1]
             self.warnings = value[2]
+            if len(value[1]) > 0 or len(value[2]) > 0:
+                self.errors = value[1]
+            else:
+                self.errors = [re.sub(r'\[.*?\] ', '', str(self.value).split("\n")[0])]
         else:
             self.value = value
+            self.errors =self.warnings = None
+
     def __str__(self):
-        return str(self.value)
+        if self.errors:
+            if isinstance(self.errors, (list, tuple)):
+                return str(self.errors[0])
+            else:
+                return str(self.errors)
+        elif self.warnings:
+            if isinstance(self.warnings, (list, tuple)):
+                return str(self.warnings[0])
+            else:
+                return str(self.warnings)
+        elif self.errors is None and self.warnings is None:
+            return str(self.value)
+        else:
+            if isinstance(self.value, (list, tuple)):
+                return re.sub(r'\[.*?\] ', '', str(self.value).split("\n")[0])
+            else:
+                return str(self.value)
+
+    def __repr__(self):
+        return f"{self.__class__.__name__}({str(self)!r})"
+
+    def __reduce__(self):
+        if hasattr(self, 'errors'):
+            return (self.__class__, ((self.value, self.errors, self.warnings),))
+        return (self.__class__, (self.value,))
+
 
 class Spec(dict):
     """Subclass of dict, representing the fields of a spec definition.
@@ -355,7 +385,7 @@ def processFilelog(h):
             r.change = int( h[ "change" ][ n ] )
             r.action = h[ "action" ][ n ]
             r.type = h[ "type" ][ n ]
-            r.time = datetime.datetime.utcfromtimestamp( int( h[ "time" ][ n ]) )
+            r.time = datetime.datetime.fromtimestamp( int( h[ "time" ][ n ]), tz=None )
             r.user = h[ "user" ][ n ]
             r.client = h[ "client" ][ n ]
             r.desc = h[ "desc" ][ n ]
@@ -595,7 +625,7 @@ class P4(P4API.P4Adapter):
         flatArgs = self.__flatten(args)
 
         if self.logger:
-            self.logger.info("p4 " + " ".join(flatArgs))
+            self.logger.info("p4 " + " ".join(str(x) for x in flatArgs))
         
         # if encoding is set, translate to Bytes
         if hasattr(self,"encoding") and self.encoding and not self.encoding == 'raw':
@@ -732,28 +762,44 @@ class P4(P4API.P4Adapter):
         result = []
         if raw:
             debugResult = []
+            file_contents = None
+
+            def flush_file_contents():
+                nonlocal file_contents
+                if file_contents is None:
+                    return
+                elif len(file_contents) == 0:
+                    # If no file contents, assume string (text)
+                    result.append("")
+                else:
+                    # Ensure all elements in file_contents are of the same type
+                    content_type = type(file_contents[0])
+                    if any(not isinstance(x, content_type) for x in file_contents):
+                        raise TypeError("Mixed types in file content.")
+                    if content_type is bytes:
+                        result.append(b"".join(file_contents))
+                    else:
+                        result.append("".join(file_contents))
+                file_contents = None
+
             for line in raw:
                 if isinstance(line, dict):
+                    flush_file_contents()
                     result.append(line)
                     if logger:
                         debugResult.append(line)
-                    result.append("")
+                    file_contents = []
                 else:
-                    # to support encoding for Python 3, we have to do a little dance
-                    # we cannot add bytes to the str "", but we expect that all lines
-                    # are either str or bytes. So if we encounter bytes, we replace the content
-                    try:
-                        result[-1] += line
-                    except TypeError:
-                        if type(line) == bytes and type(result[-1]) == str and result[-1] == "":
-                            result[-1] = line
-                        else:
-                            raise
+                    if file_contents is None:
+                        file_contents = []
+                    file_contents.append(line)
+
+            flush_file_contents()
+
             if logger:
                 logger.debug(debugResult)
-            return result
-        else:
-            return []
+
+        return result
 
     def run_resolve(self, *args, **kargs):
         if self.resolver:
@@ -774,7 +820,7 @@ class P4(P4API.P4Adapter):
         fname = self.ticket_file
         with open(fname) as f:
             tickets_raw = f.readlines()
-        pattern = re.compile('([^=]*)=(.*):([^:]*)\n')
+        pattern = re.compile(r'([^=]*)=(.*):([^:]*)\n')
         tickets = [ pattern.match(x).groups() for x in tickets_raw ]
         keys = [ "Host", "User", "Ticket" ]
         result = [ dict(zip(keys, x)) for x in tickets ]
@@ -1082,7 +1128,7 @@ def __check_version(pathToFile):
         output = output.decode('UTF-8')
     chunks = output.split(os.linesep)
     
-    pattern = re.compile("Rev. (?P<Program>.+)/(?P<Platform>.+)/(?P<Release>.+)/(?P<Patch>\d+) \((\d+/\d+/\d+)\).")
+    pattern = re.compile(r"Rev. (?P<Program>.+)/(?P<Platform>.+)/(?P<Release>.+)/(?P<Patch>\d+) \((\d+/\d+/\d+)\).")
     
     for c in chunks:
         match = pattern.match(c)
@@ -1096,6 +1142,42 @@ def __check_version(pathToFile):
                 raise Exception("{} must be at least 2015.1, not {}".format(program, version))
 
     raise Exception("Unknown P4 output : {}".format(output) )
+    
+    
+class PyKeepAlive:
+    def __init__(self):
+        self.__thread = None
+        self.__alive = 1
+
+    def isAlive(self):
+        return self.__alive
+
+    # private member function
+    def __poll(self):
+        while True:
+            if self.isAlive() == 0:
+                self.__alive = 0
+                return 0
+            time.sleep(0.5)
+
+    # private member function
+    def __executeAll(self):
+        if self.__thread and self.__thread.is_alive():
+            pass
+
+        elif self.__thread and not self.__thread.is_alive():
+            self.__thread.join()
+
+        else:
+            self.__thread = threading.Thread(target=self.__poll)
+            self.__thread.daemon = True
+            self.__thread.start()
+
+        return self.__alive
+
+    def __call__(self):
+        return self.__executeAll()
+        
 
 if __name__ == "__main__":
     p4 = P4()
