@@ -25,7 +25,7 @@ ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-$Id: //depot/r22.2/p4-python/PythonClientAPI.cpp#1 $
+$Id: //depot/r25.2/p4-python/PythonClientAPI.cpp#1 $
 *******************************************************************************/
  
 #include <Python.h>
@@ -75,6 +75,8 @@ PythonClientAPI::PythonClientAPI()
     maxResults = 0;
     maxScanRows = 0;
     maxLockTime = 0;
+    maxOpenFiles = 0;
+    maxMemory = 0;
     prog = "unnamed p4-python script";
     apiLevel = atoi( P4Tag::l_client );
     enviro = new Enviro;
@@ -157,6 +159,8 @@ PythonClientAPI::intattribute_t PythonClientAPI::intattributes[] = {
 	{ "maxresults",		&PythonClientAPI::SetMaxResults,	&PythonClientAPI::GetMaxResults },
 	{ "maxscanrows",	&PythonClientAPI::SetMaxScanRows,	&PythonClientAPI::GetMaxScanRows },
 	{ "maxlocktime",	&PythonClientAPI::SetMaxLockTime,	&PythonClientAPI::GetMaxLockTime },
+	{ "maxopenfiles",	&PythonClientAPI::SetMaxOpenFiles,	&PythonClientAPI::GetMaxOpenFiles },
+	{ "maxmemory",	&PythonClientAPI::SetMaxMemory,	&PythonClientAPI::GetMaxMemory },
 	{ "exception_level",	&PythonClientAPI::SetExceptionLevel,	&PythonClientAPI::GetExceptionLevel },
 	{ "debug",		&PythonClientAPI::SetDebug,		&PythonClientAPI::GetDebug },
 	{ "track",		&PythonClientAPI::SetTrack,		&PythonClientAPI::GetTrack },
@@ -703,7 +707,12 @@ PyObject * PythonClientAPI::ConnectOrReconnect()
     Error e;
 
     ResetFlags();
-    client.Init( &e );
+
+    {
+        ReleasePythonLock guard;    // Release GIL during connect
+        client.Init( &e );
+    }
+    
     if ( e.Test() && exceptionLevel ) {
 	Except( "P4.connect()", &e );
 	return NULL;
@@ -747,7 +756,12 @@ PyObject * PythonClientAPI::Disconnect()
     }
     
     Error	e;
-    client.Final( &e );
+
+    {
+        ReleasePythonLock guard;    // Release GIL during disconnect
+        client.Final( &e );
+    }
+    
     ResetFlags();
     
     // Clear the specdef cache.
@@ -1234,6 +1248,8 @@ void PythonClientAPI::RunCmd(const char *cmd, ClientUser *ui, int argc, char * c
     if( maxResults  )	client.SetVar( "maxResults",  maxResults  );
     if( maxScanRows )	client.SetVar( "maxScanRows", maxScanRows );
     if( maxLockTime )	client.SetVar( "maxLockTime", maxLockTime );
+    if( maxOpenFiles )	client.SetVar( "maxOpenFiles", maxOpenFiles );
+    if( maxMemory)	client.SetVar( "maxMemory", maxMemory );
 
     // if progress is set, set the progress var
     if( ((PythonClientUser*)ui)->GetProgress() != Py_None )
@@ -1266,3 +1282,12 @@ void PythonClientAPI::RunCmd(const char *cmd, ClientUser *ui, int argc, char * c
     SetCmdRun();
 
 }
+
+void PythonClientAPI::SetBreak(PythonKeepAlive* cb)
+{
+    if( IsConnected() ) {
+        debug.debug(P4PYDBG_COMMANDS, "[P4] Establish the callback" );
+        client.SetBreak(cb);
+    }
+
+}
