@@ -23,7 +23,7 @@
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
- $Id: //depot/r22.2/p4-python/SpecMgr.cpp#1 $
+ $Id: //depot/r25.2/p4-python/SpecMgr.cpp#1 $
  *******************************************************************************/
 
 /*******************************************************************************
@@ -70,7 +70,7 @@ struct specdata {
 	"Description;code:306;type:text;len:128;;"
 	"Options;code:309;type:line;len:32;val:"
 	"unlocked/locked;;"
-	"View;code:311;type:wlist;words:2;len:64;;"
+	"View;code:311;fmt:C;type:wlist;words:2;len:64;;"
     },
     {
 	"change",
@@ -101,7 +101,8 @@ struct specdata {
 	"AltRoots;code:308;type:llist;len:64;;"
 	"Options;code:309;type:line;len:64;val:"
 	"noallwrite/allwrite,noclobber/clobber,nocompress/compress,"
-	"unlocked/locked,nomodtime/modtime,normdir/rmdir;;"
+	"unlocked/locked,nomodtime/modtime,normdir/rmdir,"
+	"noaltsync/altsync;;"
 	"SubmitOptions;code:313;type:select;fmt:L;len:25;val:"
 	"submitunchanged/submitunchanged+reopen/revertunchanged/"
 	"revertunchanged+reopen/leaveunchanged/leaveunchanged+reopen;;"
@@ -111,10 +112,11 @@ struct specdata {
 	"StreamAtChange;code:316;type:line;len:64;;"
 	"ServerID;code:315;type:line;ro;len:64;;"
 	"Type;code:318;type:select;len:10;val:"
-	"writeable/readonly/graph/partitioned;;"
+	"writeable/readonly/graph/partitioned/partitioned-jnl;;"
 	"Backup;code:319;type:select;len:10;val:enable/disable;;"
-	"View;code:311;type:wlist;words:2;len:64;;"
+	"View;code:311;fmt:C;type:wlist;words:2;len:64;;"
 	"ChangeView;code:317;type:llist;len:64;;"
+	"LimitView;code:320;fmt:C;type:llist;len:64;;"
     },
     {
 	"depot",
@@ -139,6 +141,7 @@ struct specdata {
 	"MaxOpenFiles;code:413;type:word;len:12;;"
 	"MaxMemory;code:NNN;type:word;len:12;;"
 	"Timeout;code:406;type:word;len:12;;"
+	"IdleTimeout;code:NNN;type:word;len:12;;"
 	"PasswordTimeout;code:409;type:word;len:12;;"
 	"LdapConfig;code:410;type:line;len:128;;"
 	"LdapSearchQuery;code:411;type:line;len:128;;"
@@ -148,6 +151,10 @@ struct specdata {
 	"Owners;code:408;type:wlist;len:32;opt:default;;"
 	"Users;code:405;type:wlist;len:32;opt:default;;"
     },
+    {
+	"hotfiles",
+	"HotFiles;code:1051;fmt:C;type:wlist;words:1;maxwords:3;len:64;opt:default;z;;"
+    },
     {
 	"job",
 	"Job;code:101;rq;len:32;;"
@@ -168,7 +175,7 @@ struct specdata {
 	"unlocked/locked,noautoreload/autoreload;;"
 	"Revision;code:312;type:word;words:1;len:64;;"
 	"ServerID;code:315;type:line;ro;len:64;;"
-	"View;code:311;type:wlist;len:64;;"
+	"View;code:311;fmt:C;type:wlist;len:64;;"
     },
     {
 	"ldap",
@@ -235,6 +242,7 @@ struct specdata {
 	"LastPush;code:859;fmt:L;len:10;;"
 	"DepotMap;code:860;type:wlist;words:2;len:64;;"
 	"ArchiveLimits;code:862;type:wlist;words:2;len:64;;"
+	"RemoteCharset;code:863;opt:optional;type:line;len:32;;"
     },
     {
 	"repo",
@@ -292,7 +300,8 @@ struct specdata {
 	"Owner;code:704;len:32;open:isolate;;"
 	"Name;code:703;rq;type:line;len:32;open:isolate;;"
 	"Parent;code:702;rq;len:64;open:isolate;;"
-	"Type;code:708;rq;len:32;open:isolate;;"
+	"Type;code:708;rq;type:select;len:32;open:isolate;"
+	"val:mainline/virtual/development/release/task/sparsedev/sparserel;;"
 	"Description;code:709;type:text;len:128;open:isolate;;"
 	"Options;code:707;type:line;len:64;val:"
 	"allsubmit/ownersubmit,unlocked/locked,"
@@ -313,7 +322,7 @@ struct specdata {
     },
     {
 	"typemap",
-	"TypeMap;code:601;type:wlist;words:2;len:64;opt:default;z;;"
+	"TypeMap;code:601;fmt:C;type:wlist;words:2;len:64;opt:default;z;;"
     },
     {
 	"user",
